darkhistory.electrons.ics.BE_integrals — DarkHistory documentation

# darkhistory.electrons.ics.BE_integrals

Integrals over the Bose-Einstein distribution.

Functions

`F0`(a, b[, epsrel]) | Definite integral of 1/[(exp(x) - 1)].
`F1`(a, b[, epsrel]) | Definite integral of x/[(exp(x) - 1)].
`F2`(a, b[, tol]) | Definite integral of x^2/[(exp(x) - 1)]
`F_inv`(a, b[, tol]) | Definite integral of (1/x)/(exp(x) - 1).
`F_inv_3`(a, b[, tol]) | Definite integral of (1/x**3)/(exp(x) - 1).
`F_inv_5`(a, b[, tol]) | Definite integral of (1/x**5)/(exp(x) - 1).
`F_inv_a`(lowlim, a[, tol]) | Integral of 1/((x+a)(exp(x) - 1)) from lowlim to infinity.
`F_inv_n`(a, b, n[, tol]) | Definite integral of (1/x**n)/(exp(x) - 1)
`F_log`(a, b[, tol]) | Definite integral of log(x)/(exp(x) - 1).
`F_log_a`(lowlim, a[, tol]) | Integral of log(x+a)/(exp(x) - 1) from lowlim to infinity.
`F_x_log`(a, b[, tol]) | Definite integral of x log(x)/(exp(x) - 1).
`F_x_log_a`(lowlim, a[, tol]) | Integral of x log (x+a)/(exp(x) - 1) from lowlim to infinity.

#### Previous topic

darkhistory.electrons.ics

#### Next topic

darkhistory.electrons.ics.BE_integrals.F0

### This Page

Show Source